@@ -16,7 +16,7 @@ setGeneric("prepare", function(object) {standardGeneric("prepare")})
 setGeneric("setlatticecall", function(object) {standardGeneric("setlatticecall")})
 
 setGeneric("addhist", function(object, bandwidth, gridsize = 60, kernel = "normal", cbreaks = 2, storeData = TRUE, plot = TRUE, pos = -1, ...) {standardGeneric("addhist")})
-setGeneric("addtext", function(object, xcoord, ycoord, label, which = 1, plot = TRUE, pos = -1, ...) {standardGeneric("addtext")})
+setGeneric("addtext", function(object, xcoord, ycoord, label, plot = TRUE, ...) {standardGeneric("addtext")})
 setGeneric("createkey", function(object) {standardGeneric("createkey")})
 setGeneric("addkey", function(object) {standardGeneric("addkey")})
 setGeneric("createcolorkey", function(object) {standardGeneric("createcolorkey")})
